####################################################
#### Modelling and analysis of the England COPD data
####################################################
library(spdep)
library(shapefiles)
library(CARBayes)

##############################
#### Read in and plot the data
##############################
### Read in the data
observed <- read.csv(file="copdmortalityobserved.csv", row.names=1)
expected <- read.csv(file="copdmortalityexpected.csv", row.names=1)

### calculate the SMRs for each year


### Read in the shapefile
dbf <- read.dbf(dbf.name="englandlocalauthority.dbf")
dbf$dbf <- dbf$dbf[ ,c(2,1,3:7)]
shp <- read.shp(shp.name="englandlocalauthority.shp")
shp$shp[[23]]$points <- shp$shp[[23]]$points[-c(460, 461, 462, 463, 464, 465), ]


### Plot the SMR
SMRspatial <- combine.data.shapefile(SMR, shp, dbf)
range <- seq(min(SMR$SMR2010)-0.01, max(SMR$SMR2010)+0.01, length.out=11)
n.col <- length(range)-1
spplot(SMRspatial, zcol=c("SMR2010"),scales=list(draw=TRUE), 
       xlab="Easting", ylab="Northing", at=range, col="transparent",
       col.regions=hsv(0.6, seq(0.2, 1, length.out=n.col), 1))


### Create the neighbourhood matrix
W.nb <- poly2nb(SMRspatial, row.names = rownames(SMR))
W.list <- nb2listw(W.nb, style="B")
W.mat <- nb2mat(W.nb, style="B")


### Fit a CAR smoothing model and plot the resulting smoothed estimates of risk
